Stan Math Library: stan/math/prim/arr/meta/value_type.hpp Source File

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

value_type.hpp
Go to the documentation of this file.
1 #ifndef STAN_MATH_PRIM_ARR_META_VALUE_TYPE_HPP
2 #define STAN_MATH_PRIM_ARR_META_VALUE_TYPE_HPP
3
4 #include <stan/math/prim/scal/meta/value_type.hpp>
5 #include <vector>
6
7 namespace stan {
8 namespace math {
9
16 template <typename T>
17 struct value_type<std::vector<T> > {
22 typedef typename std::vector<T>::value_type type;
23 };
24
25 }
26 }
27 #endif
stan
Definition: log_sum_exp.hpp:8
std
Definition: std_numeric_limits.hpp:7
stan::math::value_type< std::vector< T > >::type
std::vector< T >::value_type type
Type of value stored in a standard vector with type T entries.
Definition: value_type.hpp:22
value_type.hpp
stan::math::value_type
Primary template class for metaprogram to compute the type of values stored in a container.
Definition: value_type.hpp:18

[ Stan Home Page ] © 2011–2016, Stan Development Team.